/** Vendor imports Go HERE */
import { Component, Input, ViewEncapsulation } from '@angular/core';
import { MTab, MCardDetails, MComponentHeaderColumn, MReportInformation, MComponentDetails, MComponentInformation, MRecommendationInformation, MSecurityDetails, MSecurityIssue, MCrowdSourcing, MGithub, MOsio, MProgressMeter, MLicensesAffected, MConflictsWithInLicenses, MStackLicenseConflictDetails, MLicenseInformation, MComponentFeedback, MFeedbackTemplate } from '../models/ui.model';
var CardDetailsComponent = /** @class */ (function () {
    function CardDetailsComponent() {
        this.details = null;
        this.tabs = [];
        this.USER_ACTION = {
            'security': 'Log a bug',
            'recommendation': 'Create work item'
        };
        this.cardTypes = {
            SECURITY: 'security',
            INSIGHTS: 'insights',
            LICENSES: 'licenses',
            COMP_DETAILS: 'compDetails'
        };
        this.titleAndDescription = (_a = {},
            _a[this.cardTypes.SECURITY] = {
                title: 'Dependencies with security issues in your stack',
                description: 'A list of the dependencies affected with common vulnerabilities and exposures (CVE), dependency with the highest common vulnerability score (CVSS), and its CVE ID. You can take corrective actions by reporting the issues.'
            },
            _a[this.cardTypes.INSIGHTS] = {
                title: 'Insights on alternate or additional dependencies that can augment your stack',
                description: 'A list of dependencies that are not commonly used in similar stacks, suggestions for alternate dependencies to replace them, and suggestions for additional dependencies to complement your stack. Take corrective action by creating a work item in planner or leave us feedback.'
            },
            _a[this.cardTypes.LICENSES] = {
                title: 'License details of dependencies in your stack',
                description: 'A list of stack and dependency level license conflicts, licenses unknown to Openshift.io and suggestions for alternate dependencies to resolve these issues. Create a work item in planner to replace these dependencies.'
            },
            _a[this.cardTypes.COMP_DETAILS] = {
                title: 'Dependency details of your manifest file',
                description: 'A list of all the analyzed dependencies that flags security, usage, and license issues in your stack and suggests alternate dependencies to replace dependencies with these issues. Take corrective action by creating a work item in planner. It also lists dependencies unknown to Openshift.io.'
            },
            _a);
        var _a;
    }
    CardDetailsComponent.prototype.ngOnInit = function () {
        this.paint();
    };
    CardDetailsComponent.prototype.ngOnChanges = function (changes) {
        var summary = changes['cardDetails'];
        if (summary) {
            this.cardDetails = summary.currentValue;
            if (this.cardDetails && this.cardDetails.report) {
                this.report = this.cardDetails.report;
            }
            else {
                this.report = null;
            }
            this.whatCard = this.cardDetails && this.cardDetails.cardType || null;
            this.paint();
        }
    };
    CardDetailsComponent.prototype.canInclude = function (cardType, component) {
        var processFlag = true;
        if (component) {
            switch (cardType) {
                case 'security':
                    processFlag = component.securityDetails && component.securityDetails.totalIssues > 0;
                    break;
                case 'insights':
                    processFlag = component.isUsageOutlier;
                    break;
                case 'licenses':
                    processFlag = component.hasLicenseIssue;
                    break;
                case 'compDetails':
                    processFlag = true;
                    break;
                default:
                    break;
            }
            return processFlag;
        }
        return false;
    };
    CardDetailsComponent.prototype.getMComponentFeedback = function (type, component) {
        var feedback = null;
        if (this.genericInformation && this.genericInformation.stackId && component) {
            feedback = new MComponentFeedback(new MFeedbackTemplate(this.genericInformation.stackId, type, component.name, null, component.ecosystem), this.genericInformation.baseUrl);
        }
        return feedback;
    };
    CardDetailsComponent.prototype.getCompanionComponents = function () {
        var _this = this;
        var companions = [];
        if (this.report) {
            if (this.report.recommendation
                && this.report.recommendation.companion
                && this.report.recommendation.companion.length > 0) {
                var comps = this.report.recommendation.companion;
                comps.forEach(function (companion) {
                    var security = _this.getComponentSecurity(companion);
                    var progress = null;
                    if (companion && companion.confidence_reason) {
                        progress = new MProgressMeter(Math.round(companion.confidence_reason) + '%', Math.round(companion.confidence_reason), Math.round(companion.confidence_reason) > 50 ? '#6ec664' : 'ORANGE', '', Math.round(companion.confidence_reason));
                    }
                    companions.push(new MRecommendationInformation('companion', companion.reason, _this.getMComponentFeedback('companion', companion), progress, new MComponentInformation(companion.name, '-----', companion.latest_version, security, security !== null, false, false, companion.licenses, new MCrowdSourcing(companion.topic_list), _this.getMGithub(companion), new MOsio(companion.osio_user_count), 'Create work item', true, null, false, null, companion.ecosystem), _this.report.manifest_file_path));
                });
            }
        }
        return companions;
    };
    CardDetailsComponent.prototype.getCompanionComponentDetails = function () {
        var comps = this.getCompanionComponents();
        var compDetails = [];
        if (comps && comps.length > 0) {
            comps.forEach(function (comp) {
                compDetails.push(new MComponentDetails(null, comp));
            });
        }
        return compDetails;
    };
    CardDetailsComponent.prototype.decideAction = function (component) {
        var action = null;
        if (component) {
            if (component.recommendation) {
                if (component.recommendation.componentInformation) {
                    action = component.recommendation.componentInformation.action;
                }
            }
            else {
                if (component.securityDetails && component.securityDetails.totalIssues > 0) {
                    action = this.USER_ACTION.security;
                }
            }
        }
        return action;
    };
    CardDetailsComponent.prototype.getUIReportInformations = function (cardType) {
        var _this = this;
        var reportInformations = [];
        var componentDetails = [];
        var componentInformation = null;
        var recommendationInformation = null;
        var securityDetails = null;
        var crowd = null;
        var github = null;
        var osio = null;
        var headers = this.fillColumnHeaders(cardType);
        var compInfoType = 'component';
        var components = null;
        if (this.report.user_stack_info
            && this.report.user_stack_info.analyzed_dependencies
            && this.report.user_stack_info.analyzed_dependencies.length > 0) {
            components = this.report.user_stack_info.analyzed_dependencies;
        }
        if (components) {
            components.forEach(function (component) {
                componentInformation = _this.getComponentInformation(component);
                if (_this.canInclude(cardType, componentInformation)) {
                    componentInformation.action = _this.decideAction(componentInformation);
                    componentDetails.push(new MComponentDetails(componentInformation, recommendationInformation));
                }
            });
        }
        var genericReport = new MReportInformation(null, null, 'component', this.fillColumnHeaders(cardType, 1), componentDetails);
        var compDetails = [];
        switch (cardType) {
            case 'security':
                genericReport.identifier = 'security';
                genericReport.name = 'securityTab';
                reportInformations.push(genericReport);
                break;
            case 'insights':
                genericReport.identifier = 'ins-usage';
                genericReport.name = 'Usage Outlier Details';
                reportInformations.push(genericReport);
                compDetails = this.getCompanionComponentDetails();
                reportInformations.push(new MReportInformation('ins-companion', 'Companion Dependency Details', 'recommendation', this.fillColumnHeaders(cardType, 2), compDetails));
                break;
            case 'licenses':
                genericReport.identifier = 'lic-conflicts';
                genericReport.name = 'Conflicting License(s) Details';
                reportInformations.push(genericReport);
                compDetails = this.getUnknownLicenseComponentDetails();
                reportInformations.push(new MReportInformation('lic-unknown', 'Unknown License(s) Details', 'component', this.fillColumnHeaders(cardType, 2), compDetails));
                break;
            case 'compDetails':
                genericReport.identifier = 'comp-analyzed';
                genericReport.name = 'Analyzed Dependency Details';
                reportInformations.push(genericReport);
                compDetails = this.getUnknownComponentDetails(cardType);
                reportInformations.push(new MReportInformation('comp-unknown', 'Unknown Dependency Details', 'component', this.fillColumnHeaders(cardType, 2), compDetails));
                break;
            default:
                break;
        }
        return reportInformations;
    };
    CardDetailsComponent.prototype.hasUnknownLicense = function (component) {
        if (component) {
            var licenseAnalysis = this.getLicensesAnalysis();
            if (licenseAnalysis &&
                licenseAnalysis.unknown_licenses &&
                licenseAnalysis.unknown_licenses.really_unknown &&
                licenseAnalysis.unknown_licenses.really_unknown.length > 0) {
                var reallyUnknown = licenseAnalysis.unknown_licenses.really_unknown;
                var len = reallyUnknown.length;
                for (var i = 0; i < len; ++i) {
                    if (reallyUnknown[i].package === component.name) {
                        return true;
                    }
                }
            }
        }
        return false;
    };
    CardDetailsComponent.prototype.getUnknownLicenseComponentDetails = function () {
        var _this = this;
        var unknownLicenseComps = null;
        var components = null;
        if (this.report.user_stack_info
            && this.report.user_stack_info.analyzed_dependencies
            && this.report.user_stack_info.analyzed_dependencies.length > 0) {
            components = this.report.user_stack_info.analyzed_dependencies;
        }
        if (components) {
            unknownLicenseComps = [];
            components.forEach(function (component) {
                if (_this.hasUnknownLicense(component)) {
                    unknownLicenseComps.push(new MComponentDetails(_this.getComponentInformation(component), null));
                }
            });
        }
        return unknownLicenseComps;
    };
    CardDetailsComponent.prototype.getUnknownComponentDetails = function (cardType) {
        var unknowns = [];
        var unknownComponents = (this.report && this.report.user_stack_info && this.report.user_stack_info.unknown_dependencies) || [];
        unknownComponents.forEach(function (unknown) {
            unknowns.push(new MComponentDetails(new MComponentInformation(unknown.name, unknown.version, '', null, null, null, null, null, null, null, null, null, false, null, false, null, null, null, null), null));
        });
        return unknowns;
    };
    CardDetailsComponent.prototype.getMGithub = function (component) {
        var github = null;
        if (component && component.github) {
            var g = component.github;
            github = new MGithub(g.contributors, g.forks_count, g.dependent_repos, g.stargazers_count, g.used_by && g.used_by.length || -1, g.used_by);
        }
        return github;
    };
    CardDetailsComponent.prototype.getLicensesAnalysis = function () {
        if (this.report) {
            if (this.report.user_stack_info
                && this.report.user_stack_info.license_analysis
                && this.report.user_stack_info.license_analysis) {
                return this.report.user_stack_info.license_analysis;
            }
        }
        return null;
    };
    CardDetailsComponent.prototype.hasLicenseIssue = function (component) {
        if (component) {
            var analysis = this.getLicensesAnalysis();
            if (analysis) {
                return (analysis.conflict_packages
                    && analysis.conflict_packages.length > 0)
                    || (analysis.unknown_licenses && analysis.unknown_licenses.component_conflict &&
                        analysis.unknown_licenses.component_conflict.length > 0);
            }
        }
        return false;
    };
    CardDetailsComponent.prototype.getComponentInformation = function (component) {
        if (component) {
            var currentVersion = component.version;
            var latestVersion = component.latest_version;
            var github = component.github;
            var hasLicenseIssue = this.hasLicenseIssue(component);
            var isUsageOutlier = false;
            var securityDetails = this.getComponentSecurity(component);
            var recommendation = this.report.recommendation;
            var recommendationInformation = null;
            var usageOutliers = null;
            if (recommendation) {
                usageOutliers = recommendation.usage_outliers;
                if (usageOutliers) {
                    var outlierLen = usageOutliers.length;
                    for (var i = 0; i < outlierLen; ++i) {
                        if (component.name === usageOutliers[i].package_name) {
                            isUsageOutlier = true;
                            break;
                        }
                    }
                }
                if (recommendation.alternate && recommendation.alternate.length > 0) {
                    var alternates = recommendation.alternate;
                    var alternatesLen = alternates.length;
                    for (var i = 0; i < alternatesLen; ++i) {
                        if (alternates[i].replaces && alternates[i].replaces[0] && alternates[i].replaces[0].name) {
                            var alternate = alternates[i];
                            if (component.name === alternate.replaces[0].name) {
                                var alterSecurity = this.getComponentSecurity(alternate);
                                var progress = null;
                                if (alternate && alternate.confidence_reason) {
                                    progress = new MProgressMeter(Math.round(alternate.confidence_reason) + '%', Math.round(alternate.confidence_reason), Math.round(alternate.confidence_reason) > 50 ? '#6ec664' : 'ORANGE', '', Math.round(alternate.confidence_reason));
                                }
                                recommendationInformation = new MRecommendationInformation('alternate', alternate.reason, this.getMComponentFeedback('alternate', alternate), progress, new MComponentInformation(alternate.name, alternate.version, alternate.latest_version, alterSecurity, alterSecurity !== null, false, false, alternate.licenses, new MCrowdSourcing(alternate.topic_list), this.getMGithub(alternate), new MOsio(alternate.osio_user_count), 'Create work item', false, null, false, null, alternate.ecosystem));
                                break;
                            }
                        }
                    }
                }
            }
            return new MComponentInformation(component.name, currentVersion, latestVersion, securityDetails, securityDetails !== null, isUsageOutlier, hasLicenseIssue, component.licenses, new MCrowdSourcing(component.topic_list), this.getMGithub(component), new MOsio(component.osio_user_count), null, true, recommendationInformation, false, new MLicenseInformation(component.licenses, this.getUnknownLicenses(component), hasLicenseIssue, this.getMLicenseAffected(component)), component.ecosystem, this.report.manifest_file_path);
        }
        return null;
    };
    CardDetailsComponent.prototype.getUnknownLicenses = function (component) {
        var unknownLicenses = [];
        if (component) {
            if (this.report) {
                var analysis = this.getLicensesAnalysis();
                if (analysis && analysis.unknown_licenses
                    && analysis.unknown_licenses.really_unknown
                    && analysis.unknown_licenses.really_unknown.length > 0) {
                    var reallyUnknown = analysis.unknown_licenses.really_unknown;
                    reallyUnknown.forEach(function (unknown) {
                        if (unknown.package === component.name) {
                            unknownLicenses.push(unknown.license);
                        }
                    });
                }
            }
        }
        return unknownLicenses;
    };
    CardDetailsComponent.prototype.getMLicenseAffected = function (component) {
        var licensesAffected = null;
        var analysis = this.getLicensesAnalysis();
        if (analysis) {
            licensesAffected = [];
            var licenseAnalysis = analysis;
            if (licenseAnalysis.status) {
                switch (licenseAnalysis.status.toLowerCase()) {
                    case 'componentconflict':
                        if (licenseAnalysis.unknown_licenses
                            && licenseAnalysis.unknown_licenses.component_conflict
                            && licenseAnalysis.unknown_licenses.component_conflict.length > 0) {
                            var compConflicts = licenseAnalysis.unknown_licenses.component_conflict;
                            var len = compConflicts.length;
                            var _loop_1 = function (i) {
                                if (compConflicts[i] && compConflicts[i].package === component.name) {
                                    var affectedLicenses_1 = [];
                                    if (compConflicts[i].conflict_licenses && compConflicts[i].conflict_licenses.length > 0) {
                                        compConflicts[i].conflict_licenses.forEach(function (license) {
                                            affectedLicenses_1.push(new MConflictsWithInLicenses(license.license1, license.license2));
                                        });
                                    }
                                    licensesAffected.push(new MLicensesAffected(affectedLicenses_1, 'componentconflict', null));
                                }
                            };
                            for (var i = 0; i < len; ++i) {
                                _loop_1(i);
                            }
                        }
                        break;
                    case 'stacklicenseconflict':
                        if (licenseAnalysis.conflict_packages
                            && licenseAnalysis.conflict_packages.length > 0) {
                            var stackConflicts = licenseAnalysis.conflict_packages;
                            var len = stackConflicts.length;
                            var affectedComponents = [];
                            for (var i = 0; i < len; ++i) {
                                if (stackConflicts[i] && stackConflicts[i].package1 === component.name) {
                                    affectedComponents.push(new MStackLicenseConflictDetails(stackConflicts[i].license2, stackConflicts[i].package2, stackConflicts[i].license1));
                                }
                            }
                            licensesAffected.push(new MLicensesAffected(null, 'stackconflict', affectedComponents));
                        }
                        break;
                    case 'successful':
                        break;
                    case 'unknown':
                        break;
                    case 'failure':
                        break;
                    default:
                }
            }
        }
        return licensesAffected;
    };
    CardDetailsComponent.prototype.getComponentSecurityInformation = function (component) {
        if (component) {
            var securityDetails = null;
            var securityIssues = 0;
            var maxIssue = null, temp = null;
            if (component.security && component.security.length > 0) {
                securityDetails = new MSecurityDetails();
                var currSecurity = component.security;
                temp = currSecurity.reduce(function (a, b) {
                    return parseFloat(a.CVSS) < parseFloat(b.CVSS) ? b : a;
                });
                if (temp) {
                    if (maxIssue === null || maxIssue.CVSS < temp.CVSS) {
                        maxIssue = temp;
                    }
                }
                securityIssues += currSecurity.length;
                securityDetails.totalIssues = securityIssues;
            }
            if (maxIssue) {
                securityDetails.highestIssue = new MSecurityIssue(maxIssue.CVSS, maxIssue.CVE);
                securityDetails.progressReport = new MProgressMeter(Number(maxIssue.CVSS) + '/10', Number(maxIssue.CVSS), Number(maxIssue.CVSS) >= 7 ? '#d1011c' : 'ORANGE', '', Number(maxIssue.CVSS) * 10);
            }
            return securityDetails;
        }
        return null;
    };
    CardDetailsComponent.prototype.getComponentSecurity = function (component) {
        return this.getComponentSecurityInformation(component);
    };
    CardDetailsComponent.prototype.getTitleAndDescription = function (cardType) {
        var _a = this.titleAndDescription[cardType], title = _a.title, description = _a.description;
        return {
            title: title,
            description: description
        };
    };
    CardDetailsComponent.prototype.fillColumnHeaders = function (cardType, tabNo) {
        if (tabNo === void 0) { tabNo = null; }
        var headers = [];
        headers.push(new MComponentHeaderColumn('serial', '#', 'float-left extra-small'));
        switch (cardType) {
            case 'security':
                headers.push(new MComponentHeaderColumn('component', 'Dependencies', 'float-left medium'));
                headers.push(new MComponentHeaderColumn('cveCount', 'No. of CVE(s)', 'float-left small'));
                headers.push(new MComponentHeaderColumn('highestCVSS', 'Highest CVSS Score', 'float-left medium'));
                headers.push(new MComponentHeaderColumn('cveIdOfH', 'CVE ID of highest CVSS score', 'float-left medium'));
                headers.push(new MComponentHeaderColumn('action', 'Action', 'float-left small'));
                break;
            case 'insights':
                headers.push(new MComponentHeaderColumn('component', 'Dependencies', 'float-left medium'));
                if (tabNo === 1) {
                    headers.push(new MComponentHeaderColumn('alternate', 'Alternate Dependencies', 'float-left medium'));
                }
                else if (tabNo === 2) {
                }
                headers.push(new MComponentHeaderColumn('confidence', 'Confidence Score', 'float-left extra-medium'));
                headers.push(new MComponentHeaderColumn('feedback', 'Feedback', 'float-left small'));
                headers.push(new MComponentHeaderColumn('action', 'Action', 'float-left small'));
                break;
            case 'licenses':
                headers.push(new MComponentHeaderColumn('component', 'Dependencies', 'float-left medium'));
                if (tabNo === 1) {
                    headers.push(new MComponentHeaderColumn('licensesAffected', 'Licenses Affected', 'float-left medium'));
                }
                else if (tabNo === 2) {
                    headers.push(new MComponentHeaderColumn('unknownLicenses', 'Unknown License', 'float-left medium'));
                }
                headers.push(new MComponentHeaderColumn('alternate', 'Alternate Dependencies', 'float-left medium'));
                headers.push(new MComponentHeaderColumn('action', 'Action', 'float-left small'));
                break;
            case 'compDetails':
                headers.push(new MComponentHeaderColumn('component', 'Dependencies', 'float-left medium'));
                if (tabNo === 1) {
                    headers.push(new MComponentHeaderColumn('componentCheck', 'Dependency Check', 'float-left medium'));
                    headers.push(new MComponentHeaderColumn('alternate', 'Alternate Dependencies', 'float-left medium'));
                    headers.push(new MComponentHeaderColumn('action', 'Action', 'float-left small'));
                }
                else if (tabNo === 2) {
                    // headers.push(new MComponentHeaderColumn(
                    //     'helpUsKnownMore',
                    //     'Help us Know more about this component',
                    //     'float-left large'
                    // ));
                    // Ignored for now
                }
                break;
            default:
                break;
        }
        headers.push(new MComponentHeaderColumn('collapse', '', 'float-right'));
        if (cardType === 'compDetails' && tabNo === 2) {
            headers.pop();
        }
        return headers;
    };
    CardDetailsComponent.prototype.paint = function () {
        var _this = this;
        this.tabs = [];
        if (this.report && this.whatCard) {
            var reports = this.getUIReportInformations(this.whatCard);
            this.details = new MCardDetails();
            var _a = this.getTitleAndDescription(this.whatCard), title = _a.title, description = _a.description;
            this.details.reportInformations = reports;
            this.details.isMultiple = true;
            this.details.title = title;
            this.details.titleDescription = description;
            if (reports && reports.length > 0) {
                reports.forEach(function (report) {
                    _this.tabs.push(new MTab(report.name, report));
                });
                if (this.tabs[0]) {
                    this.tabs[0].active = true;
                }
            }
        }
    };
    CardDetailsComponent.decorators = [
        { type: Component, args: [{
                    selector: 'card-details',
                    styles: [require('./card-details.component.css').toString()],
                    encapsulation: ViewEncapsulation.None,
                    template: require('./card-details.component.html')
                },] },
    ];
    /** @nocollapse */
    CardDetailsComponent.ctorParameters = function () { return []; };
    CardDetailsComponent.propDecorators = {
        'cardDetails': [{ type: Input },],
        'genericInformation': [{ type: Input },],
        'repoInfo': [{ type: Input },],
    };
    return CardDetailsComponent;
}());
export { CardDetailsComponent };
//# sourceMappingURL=card-details.component.js.map