/** Vendor imports Go HERE */
import { Component, Input } from '@angular/core';
import { Contexts } from 'ngx-fabric8-wit';
import { AddWorkFlowService } from '../../stack-details/add-work-flow.service';
var ComponentInformationComponent = /** @class */ (function () {
    function ComponentInformationComponent(addWorkFlowService, context) {
        var _this = this;
        this.addWorkFlowService = addWorkFlowService;
        this.context = context;
        this.workItemResponse = [];
        if (this.context && this.context.current) {
            this.context.current.subscribe(function (val) {
                if (val && val.name) {
                    _this.spaceName = val.name.trim().replace(' ', '_');
                }
                _this.userName = val.user.attributes.username;
            });
        }
        this.messages = {
            createWorkItemEerror: 'There was a error while creating work item.',
            toastDisplay: {
                text1: 'Workitem with ID ',
                text2: ' has been added to the backlog.'
            },
            viewWorkItem: 'View Work Item'
        };
    }
    ComponentInformationComponent.prototype.ngOnInit = function () {
        this.paint();
    };
    ComponentInformationComponent.prototype.ngOnChanges = function (changes) {
        var summary = changes['component'];
        if (summary) {
            this.component = summary.currentValue;
        }
        if (changes['positions']) {
            this.positions = changes['positions']['currentValue'];
        }
        this.paint();
    };
    ComponentInformationComponent.prototype.paint = function () {
        if (this.component) {
            if (this.type === 'recommendation') {
                var c = this.component;
                this.comp = c && c.componentInformation;
            }
            else {
                this.comp = this.component;
            }
        }
    };
    ComponentInformationComponent.prototype.handleAction = function (event, comp) {
        event.preventDefault();
        var workItems = [];
        var message = '';
        var codebase = {
            'repository': '',
            'branch': '',
            'filename': this.component['manifestFilePath'],
            'linenumber': 1
        };
        var key = '';
        // TODO form data to be shared with recommender object
        var titleHdr = '';
        if (comp && comp.recommendation) {
            message = "Stack analysis has identified alternate component\n            for **" + comp.name + "**.\n            You have chosen to replace **" + comp.name + "** with **" + comp.recommendation.componentInformation.name + "**\n            and version: **" + comp.recommendation.componentInformation.currentVersion + "** in your application stack";
            titleHdr = "Alternate dependencies for " + comp.name;
            key = comp.recommendation.componentInformation.name;
        }
        else if (comp && !comp.hasSecurityIssue && !comp.recommendation) {
            message = "Stack analysis has identified some additional dependencies for your\n            application stack. You have chosen to add **" + comp.name + "**\n            with **" + comp.currentVersion + "** to your application stack";
            titleHdr = "Add " + comp.name + " to your application stack";
            key = comp.name;
        }
        else if (comp && comp.hasSecurityIssue) {
            message = "Stack analysis has identified some security issues for dependency **" + comp.name + "**\n            with **" + comp.currentVersion + "** in your application stack. CVE id for the highest security issue is **" + comp.securityDetails.highestIssue.cve + "**";
            titleHdr = comp.name + " has some security issues";
            key = comp.name;
        }
        if (this.repoInfo && this.repoInfo.git) {
            codebase['repository'] = this.repoInfo.git.uri || '';
            codebase['branch'] = this.repoInfo.git.ref || 'master';
        }
        message += ' \n\n ';
        message += '\n\n **Repository:** ' + codebase['repository'];
        message += '\n\n **Branch:** ' + codebase['branch'];
        message += '\n\n **Filename:** ' + codebase['filename'];
        message += '\n\n **Line Number:**' + codebase['linenumber'];
        var item = {
            title: titleHdr,
            description: {
                content: message,
                markup: 'Markdown'
            },
            codebase: codebase,
            key: key
        };
        workItems.push(item);
        if (workItems.length > 0) {
            this.addWorkItems(workItems[0], comp);
        }
        else {
            console.log('Work items are empty and cannot be added');
        }
    };
    /*
     *  getWorkItemData - Takes nothing, returns Object
     *  It returns the predefined JSON structure to be sent as an input
     *  for work item creation request.
     */
    ComponentInformationComponent.prototype.getWorkItemData = function () {
        var workItemData = {
            'data': {
                'attributes': {
                    'system.title': '',
                    'system.codebase': ''
                },
                'type': 'workitems',
                'relationships': {
                    'baseType': {
                        'data': {
                            'id': '',
                            'type': 'workitemtypes'
                        }
                    }
                }
            }
        };
        return workItemData;
    };
    /*
     *  addWorkItems - takes workitems array, return nothing
     *  A generic function that recieves workitems in a predefined format
     *  Creates work items based on the data
     *  Handles single as well as multiple work items
     */
    ComponentInformationComponent.prototype.addWorkItems = function (workItem, comp) {
        var _this = this;
        var newItem; // , workItem: any;
        newItem = this.getWorkItemData();
        // for (let i: number = 0; i < length; ++i) {
        // if (workItems[i]) {
        // workItem = workItems[i];
        // TODO: Handle the case of sending multiple work items concurrently
        // once the API Payload is properly set at the receiving end.
        if (newItem) {
            newItem.data.attributes['system.title'] = workItem['title'];
            newItem.data.attributes['system.description'] = workItem['description'];
            newItem.data.attributes['system.codebase'] = workItem['codebase'];
            newItem.data.attributes['system.description.markup'] = workItem['markup'];
            newItem.key = workItem['key'];
        }
        // }
        // }
        var workFlow = this.addWorkFlowService.addWorkFlow(newItem);
        workFlow.subscribe(function (data) {
            if (data) {
                var inputUrlArr = [];
                if (data.links && data.links.self && data.links.self.length &&
                    data.data.attributes) {
                    comp.workItem.isWorkItemCreated = true;
                    inputUrlArr = data.links.self.split('/api/');
                    var hostString = inputUrlArr[0] ? inputUrlArr[0].replace('api.', '') : '';
                    var baseUrl = hostString +
                        ("/" + _this.userName + "/" + _this.getSpaceName(_this.spaceName) + "/plan/detail/") +
                        data.data.attributes['system.number'];
                    comp.workItem.url = baseUrl;
                    _this.displayWorkItemResponse(baseUrl, data.data.attributes['system.number']);
                    newItem.url = baseUrl;
                    // TODO :: toggle Worke item link and toast notification
                    // this.toggleWorkItemButton(newItem);
                }
            }
        });
    };
    ComponentInformationComponent.prototype.getSpaceName = function (spaceName) {
        spaceName = spaceName.replace(/\s/g, '_');
        return spaceName;
    };
    /**
     * displayWorkItemResponse - takes a message string and returns nothing
     * Displays the response received from the creation of work items
     */
    ComponentInformationComponent.prototype.displayWorkItemResponse = function (url, id) {
        var notification = {
            iconClass: '',
            alertClass: '',
            text: null,
            link: null,
            linkText: this.messages.viewWorkItem
        };
        if (id) {
            notification.iconClass = 'pficon-ok';
            notification.alertClass = 'alert-success';
            notification.text = this.messages.toastDisplay.text1 +
                id + this.messages.toastDisplay.text2;
            notification.link = url;
        }
        else {
            notification.iconClass = 'pficon-error-circle-o';
            notification.alertClass = 'alert-danger';
            notification.text = this.messages.createWorkItemEerror;
        }
        this.workItemResponse.push(notification);
    };
    ComponentInformationComponent.decorators = [
        { type: Component, args: [{
                    selector: 'component-information',
                    styles: [require('./component-information.component.css').toString()],
                    template: require('./component-information.component.html')
                },] },
    ];
    /** @nocollapse */
    ComponentInformationComponent.ctorParameters = function () { return [
        { type: AddWorkFlowService, },
        { type: Contexts, },
    ]; };
    ComponentInformationComponent.propDecorators = {
        'component': [{ type: Input },],
        'positions': [{ type: Input },],
        'genericInformation': [{ type: Input },],
        'serial': [{ type: Input },],
        'type': [{ type: Input },],
        'repoInfo': [{ type: Input },],
    };
    return ComponentInformationComponent;
}());
export { ComponentInformationComponent };
//# sourceMappingURL=component-information.component.js.map