import { Injectable } from '@angular/core';
import { Http, Response, Headers, RequestOptions } from '@angular/http';
import { AuthenticationService } from 'ngx-login-client';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/catch';
import 'rxjs/operators/map';
var FeedbackService = /** @class */ (function () {
    function FeedbackService(http, auth) {
        this.http = http;
        this.auth = auth;
        this.headers = new Headers({ 'Content-Type': 'application/json' });
        if (this.auth.getToken() !== null) {
            this.headers.set('Authorization', 'Bearer ' + this.auth.getToken());
        }
    }
    FeedbackService.prototype.submit = function (feedback) {
        var url = 'https://recommender.api.openshift.io/api/v1/user-feedback';
        var options = new RequestOptions({
            headers: this.headers
        });
        return this.http
            .post(url, JSON.stringify(feedback), options)
            .map(this.extractData)
            .catch(this.handleError);
    };
    FeedbackService.prototype.extractData = function (res) {
        var body = res.json();
        return body || {};
    };
    FeedbackService.prototype.handleError = function (error) {
        // In a real world app, we might use a remote logging infrastructure
        var errMsg;
        if (error instanceof Response) {
            var body = error.json() || '';
            var err = body.error || JSON.stringify(body);
            errMsg = error.status + " - " + (error.statusText || '') + " " + err;
        }
        else {
            errMsg = error.message ? error.message : error.toString();
        }
        console.error(errMsg);
        return Observable.throw(errMsg);
    };
    FeedbackService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    FeedbackService.ctorParameters = function () { return [
        { type: Http, },
        { type: AuthenticationService, },
    ]; };
    return FeedbackService;
}());
export { FeedbackService };
//# sourceMappingURL=feedback.service.js.map