import { Injectable } from '@angular/core';
import { Http, Response, Headers, RequestOptions } from '@angular/http';
import { AuthenticationService } from 'ngx-login-client';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/catch';
import 'rxjs/operators/map';
var PipelineInsightsService = /** @class */ (function () {
    function PipelineInsightsService(http, auth) {
        this.http = http;
        this.auth = auth;
        this.headers = new Headers({ 'Content-Type': 'application/json' });
        this.stackAnalysesUrl = '';
        if (this.auth.getToken() !== null) {
            this.headers.set('Authorization', 'Bearer ' + this.auth.getToken());
        }
    }
    PipelineInsightsService.prototype.getStackAnalyses = function (url, params) {
        var options = new RequestOptions({ headers: this.headers });
        var stackReport = null;
        if (params && params['access_token']) {
            this.headers.set('Authorization', 'Bearer ' + params['access_token']);
            options = new RequestOptions({ headers: this.headers });
        }
        return this.http.get(url, options)
            .map(this.extractData)
            .map(function (data) {
            stackReport = data;
            return stackReport;
        })
            .catch(this.handleError);
    };
    PipelineInsightsService.prototype.extractData = function (res) {
        var body = res.json() || {};
        body['statusCode'] = res.status;
        body['statusText'] = res.statusText;
        return body;
    };
    PipelineInsightsService.prototype.handleError = function (error) {
        var body = {};
        if (error instanceof Response) {
            if (error && error.status && error.statusText) {
                body = {
                    status: error.status,
                    statusText: error.statusText
                };
            }
        }
        else {
            body = {
                statusText: error.message ? error.message : error.toString()
            };
        }
        return Observable.throw(body);
    };
    PipelineInsightsService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    PipelineInsightsService.ctorParameters = function () { return [
        { type: Http, },
        { type: AuthenticationService, },
    ]; };
    return PipelineInsightsService;
}());
export { PipelineInsightsService };
//# sourceMappingURL=pipeline-insights.service.js.map