/** Vendor imports Go HERE */
import { Component, Input, Output, EventEmitter } from '@angular/core';
import { MReportSummaryCard, MReportSummaryContent, MReportSummaryInfoEntry, MReportSummaryTitle, MSecurityDetails, MSecurityIssue, MProgressMeter } from '../models/ui.model';
import { ReportSummaryUtils } from '../utils/report-summary-utils';
var ReportSummaryComponent = /** @class */ (function () {
    function ReportSummaryComponent() {
        this.onCardClick = new EventEmitter();
        this.reportSummaryCards = [];
        this.reportSummaryCardsForShort = [];
        this.notification = null;
        this.cardTypes = {
            SECURITY: 'security',
            INSIGHTS: 'insights',
            LICENSES: 'licenses',
            COMP_DETAILS: 'compDetails'
        };
        this.titleAndDescription = (_a = {},
            _a[this.cardTypes.SECURITY] = {
                title: 'Dependencies with security issues in your stack',
                description: 'OSIO Analytics identifies security issues in your stack. Click this card to see further details of the security tasks affecting your stack.'
            },
            _a[this.cardTypes.INSIGHTS] = {
                title: 'Insights on alternate or additional dependencies that can augment your stack',
                description: 'OSIO Analytics identifies dependencies that are rarely used in similar stacks, and suggests alternate and additional dependencies that can enhance your stack. Click this card to see detailed suggestions on alternate and additional dependencies.'
            },
            _a[this.cardTypes.LICENSES] = {
                title: 'License details of dependencies in your stack',
                description: 'OSIO Analytics identifies the stack level license, the conflicting licenses, and the unknown licenses for your stack. Click this card to see detailed information on the conflicting and unknown licenses in your stack.'
            },
            _a[this.cardTypes.COMP_DETAILS] = {
                title: 'Dependency details of your manifest file',
                description: 'Dependencies analyzed based on versions and popularity. Click this card to see security, license and usage information for each dependency.'
            },
            _a);
        this.reportSummaryUtils = new ReportSummaryUtils();
        this.notification = this.reportSummaryUtils.notification;
        var _a;
    }
    ReportSummaryComponent.prototype.ngOnInit = function () {
        this.paintView();
    };
    ReportSummaryComponent.prototype.ngOnChanges = function (changes) {
        var summary = changes['report'];
        if (summary) {
            this.report = summary.currentValue;
            this.repaintView();
        }
    };
    ReportSummaryComponent.prototype.handleSummaryClick = function (card) {
        if (card) {
            var cardType = card.identifier || '';
            this.onCardClick.emit({
                cardType: cardType,
                report: this.report,
                isFromShortReport: this.isFromShortReport
            });
        }
    };
    ReportSummaryComponent.prototype.newCardInstance = function () {
        var newCard = new MReportSummaryCard();
        newCard.reportSummaryContent = new MReportSummaryContent();
        newCard.reportSummaryTitle = new MReportSummaryTitle();
        return newCard;
    };
    ReportSummaryComponent.prototype.getComponentSecurityInformation = function (component) {
        if (component) {
            var securityDetails = new MSecurityDetails();
            var securityIssues = 0;
            var maxIssue = null, temp = null;
            if (component.security && component.security.length > 0) {
                var currSecurity = component.security;
                temp = currSecurity.reduce(function (a, b) {
                    return parseFloat(a.CVSS) < parseFloat(b.CVSS) ? b : a;
                });
                if (temp) {
                    if (maxIssue === null || maxIssue.CVSS < temp.CVSS) {
                        maxIssue = temp;
                    }
                }
                securityIssues += currSecurity.length;
            }
            if (maxIssue) {
                securityDetails.highestIssue = new MSecurityIssue(maxIssue.CVSS, maxIssue.CVE);
                securityDetails.progressReport = new MProgressMeter('', Number(maxIssue.CVSS), Number(maxIssue.CVSS) >= 7 ? '#ff6162' : 'ORANGE', '', Number(maxIssue.CVSS) * 10);
            }
            securityDetails.totalIssues = securityIssues;
            return securityDetails;
        }
        return null;
    };
    ReportSummaryComponent.prototype.getSecurityReportCard = function () {
        return this.reportSummaryUtils.getSecurityReportCard(this.report.user_stack_info);
    };
    ReportSummaryComponent.prototype.getInsightsReportCard = function () {
        return this.reportSummaryUtils.getInsightsReportCard(this.report.recommendation);
    };
    ReportSummaryComponent.prototype.getLicensesReportCard = function () {
        return this.reportSummaryUtils.getLicensesReportCard(this.report.user_stack_info);
    };
    ReportSummaryComponent.prototype.getComponentDetailsReportCard = function () {
        var componentDetailsCard = this.reportSummaryUtils.newCardInstance();
        componentDetailsCard.identifier = this.cardTypes.COMP_DETAILS;
        componentDetailsCard.reportSummaryTitle.titleIcon = 'fa fa-cube';
        componentDetailsCard.reportSummaryTitle.titleText = 'Dependency Details';
        componentDetailsCard.reportSummaryDescription = this.titleAndDescription[this.cardTypes.COMP_DETAILS].description;
        componentDetailsCard.reportSummaryContent.infoEntries = [];
        if (this.report.user_stack_info &&
            this.report.user_stack_info) {
            var userStackInfo = this.report.user_stack_info;
            var analyzedCount = void 0, totalCount = void 0, unknownCount = void 0;
            analyzedCount = userStackInfo.analyzed_dependencies ? userStackInfo.analyzed_dependencies.length : 0;
            totalCount = userStackInfo.dependencies ? userStackInfo.dependencies.length : 0;
            unknownCount = userStackInfo.unknown_dependencies ? userStackInfo.unknown_dependencies.length : totalCount - analyzedCount;
            var totalEntry = new MReportSummaryInfoEntry();
            totalEntry.infoText = 'Total Dependencies';
            totalEntry.infoValue = totalCount;
            var analyzedEntry = new MReportSummaryInfoEntry();
            analyzedEntry.infoText = 'Analyzed Dependencies';
            analyzedEntry.infoValue = analyzedCount;
            var unknownEntry = new MReportSummaryInfoEntry();
            unknownEntry.infoText = 'Unknown Dependencies';
            unknownEntry.infoValue = unknownCount;
            componentDetailsCard.reportSummaryContent.infoEntries.push(totalEntry);
            componentDetailsCard.reportSummaryContent.infoEntries.push(analyzedEntry);
            componentDetailsCard.reportSummaryContent.infoEntries.push(unknownEntry);
        }
        else {
            // Handle no user dependencies scenario
        }
        return componentDetailsCard;
    };
    ReportSummaryComponent.prototype.updateCards = function () {
        var cards = [];
        var cardsShort = [];
        if (this.report) {
            cards[0] = this.getSecurityReportCard();
            cards[1] = this.getLicensesReportCard();
            cards[2] = this.getInsightsReportCard();
            cards[3] = this.getComponentDetailsReportCard();
        }
        this.reportSummaryCards = cards;
        this.reportSummaryCardsForShort = cards.slice(0, 3);
        // Select the first card by default
        if (this.isFromShortReport !== 'true') {
            this.handleSummaryClick(cards[0]);
        }
    };
    ReportSummaryComponent.prototype.paintView = function () {
        this.updateCards();
    };
    ReportSummaryComponent.prototype.repaintView = function () {
        this.paintView();
    };
    ReportSummaryComponent.decorators = [
        { type: Component, args: [{
                    selector: 'analytics-report-summary',
                    styles: [require('./report-summary.component.css').toString()],
                    template: require('./report-summary.component.html')
                },] },
    ];
    /** @nocollapse */
    ReportSummaryComponent.ctorParameters = function () { return []; };
    ReportSummaryComponent.propDecorators = {
        'report': [{ type: Input },],
        'onCardClick': [{ type: Output, args: ['onCardClick',] },],
        'isFromShortReport': [{ type: Input },],
    };
    return ReportSummaryComponent;
}());
export { ReportSummaryComponent };
//# sourceMappingURL=report-summary.component.js.map