import { Injectable, Inject } from '@angular/core';
import { Http, Response, Headers, RequestOptions } from '@angular/http';
import { AuthenticationService } from 'ngx-login-client';
import { WIT_API_URL, Contexts } from 'ngx-fabric8-wit';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/catch';
import 'rxjs/operators/map';
var AddWorkFlowService = /** @class */ (function () {
    function AddWorkFlowService(http, apiUrl, auth, context) {
        this.http = http;
        this.apiUrl = apiUrl;
        this.auth = auth;
        this.context = context;
        this.headers = new Headers({ 'Content-Type': 'application/json' });
        this.workItemsRoute = 'workitems';
        this.spacesString = 'spaces';
        if (this.auth.getToken() !== null) {
            this.headers.set('Authorization', 'Bearer ' + this.auth.getToken());
        }
        this.setMetaInformation();
    }
    AddWorkFlowService.prototype.setMetaInformation = function () {
        var _this = this;
        var api = this.apiUrl;
        if (this.context && this.context.current) {
            this.context.current.subscribe(function (currentContext) {
                if (currentContext.space) {
                    _this.spaceId = currentContext.space.id;
                    _this.stackWorkItemUrl = api + _this.spacesString + '/' + _this.spaceId + '/' + _this.workItemsRoute;
                    if (currentContext.space.relationships && currentContext.space.relationships.workitemtypes && currentContext.space.relationships.workitemtypes.links) {
                        _this.fetchBugId(currentContext.space.relationships.workitemtypes.links.related);
                    }
                }
            });
        }
    };
    AddWorkFlowService.prototype.fetchBugId = function (url) {
        var _this = this;
        var options = new RequestOptions({ headers: this.headers });
        this.http.get(url, options)
            .catch(this.handleError)
            .subscribe(function (response) {
            try {
                if (response) {
                    _this.setBugId(response.json());
                }
            }
            catch (error) {
                console.log('Error converting response to JSON');
            }
        });
    };
    AddWorkFlowService.prototype.setBugId = function (response) {
        if (response && response.data) {
            var data = response.data;
            var dataItem = void 0;
            for (var i in data) {
                if (data.hasOwnProperty(i)) {
                    dataItem = data[i];
                    if (dataItem) {
                        if (dataItem.attributes) {
                            var id = dataItem.id;
                            var attributes = dataItem.attributes;
                            if (attributes && attributes['can-construct'] === true) {
                                if (!this.fallBackBugId) {
                                    this.fallBackBugId = id;
                                }
                            }
                            if (attributes && attributes.name === 'Bug') {
                                this.bugId = id;
                                break;
                            }
                        }
                    }
                }
            }
        }
    };
    AddWorkFlowService.prototype.addWorkFlow = function (workItemData) {
        workItemData.data.relationships.baseType.data.id = this.bugId || this.fallBackBugId;
        var options = new RequestOptions({ headers: this.headers });
        var body = JSON.stringify(workItemData);
        return this.http.post(this.stackWorkItemUrl, body, options)
            .map(this.extractData)
            .catch(this.handleError);
    };
    AddWorkFlowService.prototype.extractData = function (res) {
        var body = res.json();
        return body || {};
    };
    AddWorkFlowService.prototype.handleError = function (error) {
        // In a real world app, we might use a remote logging infrastructure
        var errMsg;
        if (error instanceof Response) {
            var body = error.json() || '';
            var err = body.error || JSON.stringify(body);
            errMsg = error.status + " - " + (error.statusText || '') + " " + err;
        }
        else {
            errMsg = error.message ? error.message : error.toString();
        }
        console.error(errMsg);
        return Observable.throw(errMsg);
    };
    AddWorkFlowService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    AddWorkFlowService.ctorParameters = function () { return [
        { type: Http, },
        { type: undefined, decorators: [{ type: Inject, args: [WIT_API_URL,] },] },
        { type: AuthenticationService, },
        { type: Contexts, },
    ]; };
    return AddWorkFlowService;
}());
export { AddWorkFlowService };
//# sourceMappingURL=add-work-flow.service.js.map