import { Component, Input, ViewChild, ViewEncapsulation } from '@angular/core';
import { StackAnalysesService } from '../stack-analyses.service';
import { getStackReportModel } from '../utils/stack-api-utils';
import { ReportSummaryUtils } from '../utils/report-summary-utils';
/**
 * New Stack Report Revamp - Begin
 */
import { MGenericStackInformation } from '../models/ui.model';
import { SaveState } from '../utils/SaveState';
import { CommonService } from '../utils/common.service';
/**
 * New Stack Report Revamp - End
 */
var StackDetailsComponent = /** @class */ (function () {
    function StackDetailsComponent(stackAnalysisService, commonService) {
        this.stackAnalysisService = stackAnalysisService;
        this.commonService = commonService;
        /**
         * New Stack Report Revamp - Begin
         */
        this.cardDetails = {};
        this.genericInformation = null;
        /**
         * New Stack Report Revamp - End
         */
        this.errorMessage = {};
        this.cache = '';
        this.modalHeader = null;
        this.componentLevelInformation = {};
        this.userComponentInformation = [];
        this.companionLevelRecommendation = {};
        this.dataLoaded = false;
        this.recommendationsArray = [];
        this.stackLevelOutliers = {};
        this.companionLevel = {};
        this.componentLevel = {};
        this.componentFilterBy = '';
        this.customClass = 'accordion-custom';
        this.analysis = {};
        this.feedbackConfig = {};
        this.tabs = [];
        this.showF = true;
        this.userStackInformationArray = [];
        this.reportSummaryUtils = new ReportSummaryUtils();
    }
    /**
     * New Stack Report Revamp - Begin
     */
    StackDetailsComponent.prototype.handleCardClick = function (cardDetails) {
        this.genericInformation = new MGenericStackInformation(this.stackId, this.getBaseUrl(this.stack));
        this.cardDetails = cardDetails;
    };
    /**
     * New Stack Report Revamp - End
     */
    StackDetailsComponent.prototype.showStackModal = function (event) {
        if (event) {
            event.preventDefault();
        }
        this.modalStackModule.open();
    };
    /**
     * Gets triggered on close of modal,
     * Clears the existing states to make it proper on open
     */
    StackDetailsComponent.prototype.handleModalClose = function () {
        this.resetFields();
        SaveState.isModalOpened = false;
    };
    StackDetailsComponent.prototype.tabSelection = function (tab) {
        if (tab) {
            tab['active'] = true;
            var currentIndex = tab['index'];
            var recommendations = this.recommendationsArray[currentIndex];
            var alternate = 0, companion = 0;
            if (recommendations) {
                this.stackLevelOutliers = {
                    'usage': recommendations.usage_outliers
                };
                this.companionLevelRecommendation = {
                    dependencies: recommendations.companion,
                    manifestinfo: tab.content.manifest_name,
                    licenseAnalysis: tab.content.user_stack_info.license_analysis
                };
                alternate = recommendations.alternate ? recommendations.alternate.length : 0;
                companion = recommendations.companion ? recommendations.companion.length : 0;
            }
            var total = 0;
            var analyzed = 0;
            var unknown = 0;
            if (tab.content && tab.content.user_stack_info) {
                var userStackInfo = tab.content.user_stack_info;
                if (userStackInfo.dependencies) {
                    analyzed = userStackInfo.analyzed_dependencies.length;
                }
                if (userStackInfo.analyzed_dependencies) {
                    total = userStackInfo.dependencies.length;
                }
                if (userStackInfo.unknown_dependencies) {
                    unknown = userStackInfo.unknown_dependencies.length;
                }
            }
            this.analysis = {
                stackLevel: 'Total: ' + total + ' | Analyzed: ' + analyzed + ' | Unknown: ' +
                    unknown,
                alternate: '[' + alternate + ' alternate dependencies match your stack ' +
                    'composition and may be more appropriate]',
                companion: '[' + companion + ' additional dependencies are often used by ' +
                    'similar stacks]'
            };
            this.componentLevelInformation = {
                recommendations: recommendations,
                dependencies: tab.content.user_stack_info.analyzed_dependencies,
                manifestinfo: tab.content.manifest_name,
                licenseAnalysis: tab.content.user_stack_info.license_analysis
            };
            // Select the first card by default
            if (SaveState && SaveState.ELEMENTS && SaveState.ELEMENTS.length > 0) {
                if (SaveState.ELEMENTS[currentIndex * 4]) {
                    SaveState.ELEMENTS[currentIndex * 4].click();
                }
            }
        }
    };
    StackDetailsComponent.prototype.tabDeSelection = function (tab) {
        if (tab) {
            tab['active'] = false;
        }
    };
    StackDetailsComponent.prototype.ngOnChanges = function () {
        if (this.stack && this.stack !== this.cache) {
            this.cache = this.stack;
            this.resetFields();
            if (this.stack && this.stack.split('/').length > 0) {
                var chunks = this.stack.split('/');
                var count = chunks.length;
                this.stackId = chunks[count - 1];
            }
            // this.init(this.stack);
            this.initFeedback();
            this.componentLevel = {
                header: 'Analysis of your application stack',
                subHeader: 'Recommended alternative dependencies'
            };
            this.companionLevel = {
                header: 'Possible companion dependencies',
                subHeader: 'Consider theses additional dependencies'
            };
            this.displayName = this.displayName || 'Stack Report';
        }
        if (this.showFlags === 'false') {
            this.showF = false;
        }
    };
    StackDetailsComponent.prototype.ngOnInit = function () {
        var _this = this;
        if (SaveState.isModalOpened === false) {
            SaveState.isModalOpened = true;
            this.commonService.inshortCardClicked
                .subscribe(function (response) {
                _this.showStackModal(null);
            });
        }
    };
    StackDetailsComponent.prototype.handleChangeFilter = function (filterBy) {
        this.componentFilterBy = filterBy.filterBy;
    };
    /**
     * New Revamp - Begin
     * https://recommender.api.openshift.io/api/v1/stack-analyses/
     */
    StackDetailsComponent.prototype.getBaseUrl = function (url) {
        if (url && url !== '') {
            var splitter = 'api/v1';
            return url.indexOf(splitter) !== -1 ? url.split(splitter)[0] : '';
        }
        return '';
    };
    /**
     * New Revamp - End
     */
    StackDetailsComponent.prototype.handleError = function (error) {
        this.errorMessage = error;
        this.modalHeader = error.title;
        this.dataLoaded = true;
    };
    StackDetailsComponent.prototype.initFeedback = function () {
        this.feedbackConfig = {
            name: 'Feedback',
            stackId: this.stackId,
            title: 'Tell us your experience',
            poll: [{
                    question: 'How useful do you find this?',
                    type: 'rating'
                }, {
                    question: 'How likely do you recommend this to others?',
                    type: 'rating'
                }, {
                    question: 'Tell us more',
                    type: 'text'
                }]
        };
    };
    StackDetailsComponent.prototype.resetFields = function () {
        this.tabs.length = 0;
        this.dataLoaded = false;
        this.errorMessage = null;
        this.recommendationsArray = [];
        this.stackLevelOutliers = {};
        this.componentLevelInformation = {};
        this.companionLevelRecommendation = {};
        this.cacheResponse = {};
        SaveState.ELEMENTS = [];
        this.openStackModalFromCard = 'false';
    };
    StackDetailsComponent.prototype.handleResponse = function (data) {
        var _this = this;
        this.errorMessage = null;
        this.tabs = [];
        if (data && (!data.hasOwnProperty('error') && Object.keys(data).length !== 0)) {
            var resultInformation = getStackReportModel(data);
            resultInformation.subscribe(function (response) {
                var result = response.result;
                _this.totalManifests = result.length;
                if (_this.totalManifests > 0) {
                    _this.userStackInformationArray = result.map(function (r) { return r.user_stack_info; });
                    result.forEach(function (r, index) {
                        var warning = _this.ifManifestHasWarning(r);
                        var tab = {
                            title: r.manifest_file_path,
                            content: r,
                            index: index,
                            hasWarning: warning.has,
                            severity: warning.severity
                        };
                        _this.tabs.push(tab);
                        _this.recommendationsArray.push(r.recommendation);
                    });
                    _this.modalHeader = 'Updated just now';
                    _this.dataLoaded = true;
                    _this.tabSelection(_this.tabs[0]);
                }
            });
        }
        else if (data && data.hasOwnProperty('error')) {
            this.handleError({
                message: 'Analysis for your stack is in progress ...',
                code: data.statusCode,
                title: 'Report is getting ready.'
            });
        }
        else {
            this.handleError({
                message: data.error,
                code: data.statusCode,
                title: 'Updating ...'
            });
        }
    };
    StackDetailsComponent.prototype.ifManifestHasWarning = function (manifest) {
        var securityInfo = this.reportSummaryUtils.getSecurityReportCard(manifest.user_stack_info);
        var isSecurityWarning = securityInfo.hasWarning;
        var isInsightsWarning = this.reportSummaryUtils.getInsightsReportCard(manifest.recommendation).hasWarning;
        var isLicenseWarning = this.reportSummaryUtils.getLicensesReportCard(manifest.user_stack_info).hasWarning;
        return {
            has: isSecurityWarning || isInsightsWarning || isLicenseWarning,
            severity: (isSecurityWarning && securityInfo.severity) || 2
        };
    };
    StackDetailsComponent.prototype.init = function () {
        var _this = this;
        if (this.stackResponse && this.cacheResponse !== this.stackResponse) {
            this.cacheResponse = this.stackResponse;
            // Change this to some other logic
            setTimeout(function () {
                _this.handleResponse(_this.stackResponse);
            }, 1000);
        }
        else {
            console.log('stack details', this.stack, this.gatewayConfig);
            if (this.stack && this.stack !== '') {
                this.stackAnalysisService
                    .getStackAnalyses(this.stack, this.gatewayConfig)
                    .subscribe(function (data) {
                    _this.handleResponse(data);
                }, function (error) {
                    var title = '';
                    if (error.status >= 500) {
                        title = 'Something unexpected happened';
                    }
                    else if (error.status === 404) {
                        title = 'You are looking for something which isn\'t there';
                    }
                    else if (error.status === 401) {
                        title = 'You don\'t seem to have sufficient privileges to access this';
                    }
                    title = 'Report failed ...'; // Check if just this message is enough.
                    _this.handleError({
                        message: error.statusText,
                        status: error.status,
                        title: title
                    });
                });
            }
        }
    };
    StackDetailsComponent.decorators = [
        { type: Component, args: [{
                    selector: 'stack-details',
                    providers: [StackAnalysesService],
                    encapsulation: ViewEncapsulation.None,
                    styles: [require('./stack-details.component.css').toString()],
                    template: require('./stack-details.component.html')
                },] },
    ];
    /** @nocollapse */
    StackDetailsComponent.ctorParameters = function () { return [
        { type: StackAnalysesService, },
        { type: CommonService, },
    ]; };
    StackDetailsComponent.propDecorators = {
        'gatewayConfig': [{ type: Input },],
        'stack': [{ type: Input },],
        'displayName': [{ type: Input },],
        'repoInfo': [{ type: Input },],
        'buildNumber': [{ type: Input },],
        'appName': [{ type: Input },],
        'stackResponse': [{ type: Input },],
        'showFlags': [{ type: Input },],
        'openStackModalFromCard': [{ type: Input },],
        'modalStackModule': [{ type: ViewChild, args: ['stackModule',] },],
    };
    return StackDetailsComponent;
}());
export { StackDetailsComponent };
//# sourceMappingURL=stack-details.component.js.map