import { Component, Input, ViewEncapsulation } from '@angular/core';
import { StackAnalysesService } from '../stack-analyses.service';
import { getStackReportModel } from '../utils/stack-api-utils';
import { ReportSummaryUtils } from '../utils/report-summary-utils';
import { CommonService } from '../utils/common.service';
var StackReportInShortComponent = /** @class */ (function () {
    function StackReportInShortComponent(stackAnalysisService, commonService) {
        this.stackAnalysisService = stackAnalysisService;
        this.commonService = commonService;
        this.tabs = [];
        this.dataLoaded = false;
        this.cache = '';
        this.reportSummaryUtils = new ReportSummaryUtils();
    }
    StackReportInShortComponent.prototype.ngOnChanges = function () {
        var _this = this;
        if (this.stackUrl && this.stackUrl !== this.cache) {
            this.cache = this.stackUrl;
            this.dataLoaded = false;
            console.log('inshort component', this.stackUrl, this.gatewayConfig);
            this.stackAnalysisService
                .getStackAnalyses(this.stackUrl, this.gatewayConfig)
                .subscribe(function (data) {
                if (data && (!data.hasOwnProperty('error') && Object.keys(data).length !== 0)) {
                    var resultInformation = getStackReportModel(data);
                    if (resultInformation) {
                        resultInformation.subscribe(function (response) {
                            _this.result = response;
                            _this.buildReportInShort();
                        });
                    }
                }
                else if (data && data.hasOwnProperty('error')) {
                    // Handle Errors here 'API error'
                    _this.handleProgress({
                        title: 'Analysis for your stack is in progress...'
                    });
                }
                else {
                    // Handle Errors here 'API error'
                    _this.handleError({
                        title: 'We encountered an unexpected server error',
                        detail: data.error
                    });
                }
            }, function (error) {
                // Handle server errors here
                _this.handleError({
                    title: 'We encountered an unexpected server error'
                });
            });
        }
        else {
        }
    };
    StackReportInShortComponent.prototype.handleError = function (error) {
        this.error = error;
        this.dataLoaded = true;
    };
    StackReportInShortComponent.prototype.handleProgress = function (data) {
        this.progress = data;
        this.dataLoaded = true;
    };
    StackReportInShortComponent.prototype.tabSelection = function (tab) {
        tab['active'] = true;
        var currentIndex = tab['index'];
        this.stackLevel = tab.content.user_stack_info;
        this.recommendations = tab.content.recommendation;
        if (this.recommendations) {
            this.stackLevelOutliers = {
                'usage': this.recommendations.usage_outliers
            };
        }
        this.handleLicenseInformation(this.stackLevel);
        this.handleSecurityInformation(this.stackLevel);
    };
    StackReportInShortComponent.prototype.handleCardClick = function (cardDetails) {
        this.commonService.shortCardClicked();
    };
    StackReportInShortComponent.prototype.sortChartColumnData = function (array) {
        return array.sort(function (a, b) {
            if (a[1] === b[1]) {
                return 0;
            }
            return a[1] > b[1] ? -1 : 1;
        });
    };
    StackReportInShortComponent.prototype.handleSecurityInformation = function (tab) {
        var dependencies = tab.analyzed_dependencies;
        var security = [];
        var temp = [];
        dependencies.forEach(function (dependency) {
            security = dependency.security;
            if (security && security.length > 0) {
                var max = security.reduce(function (a, b) {
                    return parseFloat(a['CVSS']) < parseFloat(b['CVSS']) ? b : a;
                });
                temp.push({
                    name: dependency.name,
                    cve: max
                });
            }
        });
        if (temp.length > 0) {
            var final = temp.reduce(function (a, b) {
                return parseFloat(a['cve']['CVSS']) < parseFloat(b['cve']['CVSS']) ? b : a;
            });
            var cvssValue = final.cve.CVSS;
            var indicator = void 0;
            var iconClass = 'fa fa-shield';
            var displayClass = 'progress-bar-warning';
            if (cvssValue < 0) {
                indicator = -1;
            }
            if (cvssValue >= 7.0) {
                indicator = cvssValue;
                iconClass = 'fa fa-shield';
                displayClass = 'progress-bar-danger';
            }
            this.securityInfo = {
                name: final.name,
                cve: final.cve,
                percentage: final.cve.CVSS * 10,
                status: final.cve.CVSS < 7 ? 'moderate' : 'critical',
                iconClass: iconClass,
                displayClass: displayClass
            };
        }
    };
    StackReportInShortComponent.prototype.handleLicenseInformation = function (tab) {
        this.licenseAnalysis = {
            licenseOutliersCount: 0,
            licenseStackConflictCount: 0,
            licenseComponentConflictCount: 0,
            licenseUnknownCount: 0,
            stackLicenseText: '',
            status: ''
        };
        if (tab.license_analysis) {
            this.licenseAnalysis.licenseOutliersCount =
                tab.license_analysis.outlier_packages ?
                    tab.license_analysis.outlier_packages.length : 0;
            this.licenseAnalysis.licenseStackConflictCount =
                tab.license_analysis.conflict_packages ?
                    tab.license_analysis.conflict_packages.length : 0;
            if (tab.license_analysis.unknown_licenses) {
                this.licenseAnalysis.licenseUnknownCount =
                    tab.license_analysis.unknown_licenses.really_unknown ?
                        tab.license_analysis.unknown_licenses.really_unknown.length : 0;
                this.licenseAnalysis.licenseComponentConflictCount =
                    tab.license_analysis.unknown_licenses.component_conflict ?
                        tab.license_analysis.unknown_licenses.component_conflict.length : 0;
            }
            this.licenseAnalysis.stackLicenseText = tab.license_analysis.f8a_stack_licenses[0];
            if (tab.license_analysis.status) {
                this.licenseAnalysis.status = tab.license_analysis.status;
            }
            else {
                this.licenseAnalysis.status = 'nolicensedata';
            }
        }
    };
    StackReportInShortComponent.prototype.resetFields = function () {
        this.securityInfo = null;
        this.stackLevelOutliers = null;
        this.stackLevel = null;
        this.licenseAnalysis = null;
    };
    StackReportInShortComponent.prototype.buildReportInShort = function () {
        var _this = this;
        this.resetFields();
        var resultInformation = this.result.result;
        if (resultInformation && resultInformation.length > 0) {
            resultInformation.forEach(function (one, index) {
                var warning = _this.ifManifestHasWarning(one);
                _this.tabs[index] = {
                    title: one.manifest_file_path,
                    content: one,
                    index: index,
                    hasWarning: warning.has,
                    severity: warning.severity
                };
            });
            if (this.tabs[0])
                this.tabs[0]['active'] = true;
            this.tabSelection(this.tabs[0]);
            this.dataLoaded = true;
            this.error = null;
        }
    };
    StackReportInShortComponent.prototype.ifManifestHasWarning = function (manifest) {
        var securityInfo = this.reportSummaryUtils.getSecurityReportCard(manifest.user_stack_info);
        var isSecurityWarning = securityInfo.hasWarning;
        var isInsightsWarning = this.reportSummaryUtils.getInsightsReportCard(manifest.recommendation).hasWarning;
        var isLicenseWarning = this.reportSummaryUtils.getLicensesReportCard(manifest.user_stack_info).hasWarning;
        return {
            has: isSecurityWarning || isInsightsWarning || isLicenseWarning,
            severity: (isSecurityWarning && securityInfo.severity) || 2
        };
    };
    StackReportInShortComponent.decorators = [
        { type: Component, args: [{
                    selector: 'stack-report-inshort',
                    providers: [StackAnalysesService],
                    encapsulation: ViewEncapsulation.None,
                    styles: [require('./stack-report-inshort.component.css').toString()],
                    template: require('./stack-report-inshort.component.html')
                },] },
    ];
    /** @nocollapse */
    StackReportInShortComponent.ctorParameters = function () { return [
        { type: StackAnalysesService, },
        { type: CommonService, },
    ]; };
    StackReportInShortComponent.propDecorators = {
        'gatewayConfig': [{ type: Input },],
        'stackUrl': [{ type: Input },],
        'repoInfo': [{ type: Input },],
        'buildNumber': [{ type: Input },],
        'appName': [{ type: Input },],
        'pipeline': [{ type: Input },],
    };
    return StackReportInShortComponent;
}());
export { StackReportInShortComponent };
//# sourceMappingURL=stack-report-inshort.component.js.map