import { MReportSummaryCard, MReportSummaryInfoEntry, MReportSummaryContent, MReportSummaryTitle } from '../models/ui.model';
var ReportSummaryUtils = /** @class */ (function () {
    function ReportSummaryUtils() {
        this.notification = {
            warning: {
                bg: '#f5a625',
                icon: 'pficon-warning-triangle-o'
            },
            good: {
                bg: '#6dc663',
                icon: 'fa fa-check'
            }
        };
        this.colors = {
            security: {
                warning: '#d1011c',
                moderate: '#f5a625'
            },
            confidence: {
                good: '#6dc663'
            }
        };
        this.cardTypes = {
            SECURITY: 'security',
            INSIGHTS: 'insights',
            LICENSES: 'licenses',
            COMP_DETAILS: 'compDetails'
        };
        this.titleAndDescription = (_a = {},
            _a[this.cardTypes.SECURITY] = {
                title: 'Dependencies with security issues in your stack',
                description: 'Dependencies with high common vulnerabilities and exposures (CVE) score.  Click this card to see the details of all CVE(s).',
                descriptionShort: 'Click this card to see details of CVEs in your stack.'
            },
            _a[this.cardTypes.INSIGHTS] = {
                title: 'Insights on alternate or additional dependencies that can augment your stack',
                description: 'Suggested dependencies that can be added to your application stack or replace current dependencies with alternate one. Click to see details.',
                descriptionShort: 'Click this card to see suggested dependencies that complement your stack.'
            },
            _a[this.cardTypes.LICENSES] = {
                title: 'License details of dependencies in your stack',
                description: 'Recommended license for your application stack, flag any unknown/restrictive license(s) present. Click this card to see the detailed information.',
                descriptionShort: 'Click this card to see detailed license information for your stack.'
            },
            _a[this.cardTypes.COMP_DETAILS] = {
                title: 'Dependency details of your manifest file',
                description: 'Dependencies analyzed based on versions and popularity. Click this card to see security, license and usage information for each dependency.'
            },
            _a);
        var _a;
    }
    ReportSummaryUtils.prototype.newCardInstance = function () {
        var newCard = new MReportSummaryCard();
        newCard.reportSummaryContent = new MReportSummaryContent();
        newCard.reportSummaryTitle = new MReportSummaryTitle();
        return newCard;
    };
    ReportSummaryUtils.prototype.getSecurityReportCard = function (userStackInfo) {
        var securityCard = this.newCardInstance();
        securityCard.identifier = this.cardTypes.SECURITY;
        securityCard.reportSummaryTitle.titleIcon = 'fa fa-shield';
        securityCard.reportSummaryDescription =
            this.titleAndDescription[this.cardTypes.SECURITY].description;
        securityCard.reportSummaryDescriptionShort =
            this.titleAndDescription[this.cardTypes.SECURITY].descriptionShort;
        securityCard.reportSummaryTitle.titleText = 'Security Issues';
        securityCard.reportSummaryContent.infoEntries = [];
        if (userStackInfo &&
            userStackInfo.analyzed_dependencies &&
            userStackInfo.analyzed_dependencies.length > 0) {
            var securityIssues_1 = 0;
            var maxIssue_1 = null, temp_1 = null;
            var analyzedDependencies = void 0;
            analyzedDependencies = userStackInfo.analyzed_dependencies;
            analyzedDependencies.forEach(function (analyzed) {
                if (analyzed.security && analyzed.security.length > 0) {
                    var currSecurity = analyzed.security;
                    temp_1 = currSecurity.reduce(function (a, b) {
                        return parseFloat(a.CVSS) < parseFloat(b.CVSS) ? b : a;
                    });
                    if (temp_1) {
                        if (maxIssue_1 === null || maxIssue_1.CVSS < temp_1.CVSS) {
                            maxIssue_1 = temp_1;
                        }
                    }
                    securityIssues_1 += currSecurity.length;
                }
            });
            var totalComponentsWithMaxScore_1 = 0;
            analyzedDependencies.forEach(function (analyzed) {
                if (analyzed.security && analyzed.security.length > 0) {
                    var currSecurity = analyzed.security;
                    var filters = void 0;
                    filters = currSecurity.filter(function (security) {
                        return security.CVSS === maxIssue_1.CVSS;
                    });
                    totalComponentsWithMaxScore_1 += filters ? filters.length : 0;
                }
            });
            var totalIssuesEntry = new MReportSummaryInfoEntry();
            totalIssuesEntry.infoText = 'Total issues found';
            totalIssuesEntry.infoValue = securityIssues_1;
            securityCard.reportSummaryContent.infoEntries.push(totalIssuesEntry);
            if (maxIssue_1) {
                var securityColor = Number(maxIssue_1.CVSS) >= 7 ? this.colors.security.warning : this.colors.security.moderate;
                var maxIssueEntry = new MReportSummaryInfoEntry();
                maxIssueEntry.infoText = 'Highest CVSS Score';
                maxIssueEntry.infoValue = maxIssue_1.CVSS;
                maxIssueEntry.infoType = 'progress';
                maxIssueEntry.config = {
                    headerText: maxIssue_1.CVSS + ' / ' + 10,
                    value: Number(maxIssue_1.CVSS),
                    bgColor: securityColor,
                    footerText: 'No. of dependencies with this CVSS Score: ' + totalComponentsWithMaxScore_1,
                    width: Number(maxIssue_1.CVSS) * 10
                };
                securityCard.reportSummaryContent.infoEntries.push(maxIssueEntry);
                securityCard.reportSummaryTitle.notificationIcon = this.notification.warning.icon;
                securityCard.reportSummaryTitle.notificationIconBgColor = securityColor;
                securityCard.hasWarning = true;
                securityCard.severity = Number(maxIssue_1.CVSS) >= 7 ? 1 : 2;
            }
            else {
                // securityCard.reportSummaryTitle.notificationIcon = this.notification.good.icon;
                // securityCard.reportSummaryTitle.notificationIconBgColor = this.notification.good.bg;
                securityCard.hasWarning = false;
            }
        }
        else {
            // Handle for no analyzed_dependencies
        }
        return securityCard;
    };
    ReportSummaryUtils.prototype.getInsightsReportCard = function (recommendation) {
        var insightsCard = this.newCardInstance();
        insightsCard.identifier = this.cardTypes.INSIGHTS;
        insightsCard.reportSummaryTitle.titleText = 'Insights';
        insightsCard.reportSummaryTitle.titleIcon = 'pficon-zone';
        insightsCard.reportSummaryDescription = this.titleAndDescription[this.cardTypes.INSIGHTS].description;
        insightsCard.reportSummaryDescriptionShort = this.titleAndDescription[this.cardTypes.INSIGHTS].descriptionShort;
        insightsCard.reportSummaryContent.infoEntries = [];
        var usageOutliersCount = 0, companionCount = 0;
        if (recommendation) {
            var usage = recommendation.usage_outliers;
            usageOutliersCount = usage ? usage.length : 0;
            companionCount = recommendation.companion ? recommendation.companion.length : 0;
            var totalInsights = new MReportSummaryInfoEntry();
            totalInsights.infoText = 'Total Insights';
            totalInsights.infoValue = usageOutliersCount + companionCount;
            insightsCard.reportSummaryContent.infoEntries.push(totalInsights);
            var outliersInsights = new MReportSummaryInfoEntry();
            outliersInsights.infoText = 'Usage Outliers';
            outliersInsights.infoValue = usageOutliersCount;
            insightsCard.reportSummaryContent.infoEntries.push(outliersInsights);
            var companionInsights = new MReportSummaryInfoEntry();
            companionInsights.infoText = 'Companion Dependencies';
            companionInsights.infoValue = companionCount;
            insightsCard.reportSummaryContent.infoEntries.push(companionInsights);
            // insightsCard.reportSummaryTitle.notificationIcon = this.notification.good.icon;
            // insightsCard.reportSummaryTitle.notificationIconBgColor = this.notification.good.bg;
            insightsCard.hasWarning = false;
            if (usageOutliersCount > 0) {
                insightsCard.reportSummaryTitle.notificationIcon = this.notification.warning.icon;
                insightsCard.reportSummaryTitle.notificationIconBgColor = this.colors.security.moderate;
                insightsCard.hasWarning = true;
            }
        }
        else {
            // Handle no recommendations block scenario
        }
        return insightsCard;
    };
    ReportSummaryUtils.prototype.getLicensesReportCard = function (userStackInfo) {
        var licensesCard = this.newCardInstance();
        licensesCard.identifier = this.cardTypes.LICENSES;
        licensesCard.reportSummaryTitle.titleText = 'Licenses';
        licensesCard.reportSummaryTitle.titleIcon = 'fa fa-file-text-o';
        licensesCard.reportSummaryDescription = this.titleAndDescription[this.cardTypes.LICENSES].description;
        licensesCard.reportSummaryDescriptionShort = this.titleAndDescription[this.cardTypes.LICENSES].descriptionShort;
        licensesCard.reportSummaryContent.infoEntries = [];
        if (userStackInfo &&
            userStackInfo.license_analysis) {
            var licenseAnalysis = void 0;
            licenseAnalysis = userStackInfo.license_analysis;
            var stackLicense = new MReportSummaryInfoEntry();
            stackLicense.infoText = 'Recommended License';
            var stackLicenses = licenseAnalysis.f8a_stack_licenses;
            if (stackLicenses) {
                if (stackLicenses.length > 0) {
                    stackLicense.infoValue = stackLicenses[0];
                }
                else {
                    stackLicense.infoValue = 'None';
                    if (licenseAnalysis.status && licenseAnalysis.status.toLowerCase() === 'failure') {
                        stackLicense.infoValue = 'Unknown';
                    }
                }
            }
            else {
                // Null
            }
            licensesCard.reportSummaryContent.infoEntries.push(stackLicense);
            var conflictLicense = new MReportSummaryInfoEntry();
            conflictLicense.infoText = 'License Conflicts';
            var conflictLicenses = licenseAnalysis.conflict_packages;
            conflictLicense.infoValue = conflictLicenses ? conflictLicenses.length : 0;
            if (stackLicense.infoValue === 'Unknown') {
                conflictLicense.infoValue = 'NA';
            }
            licensesCard.reportSummaryContent.infoEntries.push(conflictLicense);
            var unknownLicense = new MReportSummaryInfoEntry();
            unknownLicense.infoText = 'Unknown Licenses';
            var unknownLicenses = licenseAnalysis.unknown_licenses.really_unknown;
            unknownLicense.infoValue = unknownLicenses ? unknownLicenses.length : 0;
            if (stackLicense.infoValue === 'Unknown') {
                unknownLicense.infoValue = 'NA';
            }
            licensesCard.reportSummaryContent.infoEntries.push(unknownLicense);
            if (stackLicense.infoValue !== 'NONE' && stackLicense.infoValue !== 'Unknown') {
                var restrictiveLicenses = new MReportSummaryInfoEntry();
                restrictiveLicenses.infoText = 'Restrictive Licenses';
                var restrictive = licenseAnalysis.outlier_packages;
                restrictiveLicenses.infoValue = restrictive ? restrictive.length : 0;
                licensesCard.reportSummaryContent.infoEntries.push(restrictiveLicenses);
            }
            // licensesCard.reportSummaryTitle.notificationIcon = this.notification.good.icon;
            // licensesCard.reportSummaryTitle.notificationIconBgColor = this.notification.good.bg;
            licensesCard.hasWarning = false;
            if (conflictLicenses.length > 0 || unknownLicenses.length > 0) {
                licensesCard.reportSummaryTitle.notificationIcon = this.notification.warning.icon;
                licensesCard.reportSummaryTitle.notificationIconBgColor = this.notification.warning.bg;
                licensesCard.hasWarning = true;
            }
        }
        else {
            // Handle no licenses section scenario
        }
        return licensesCard;
    };
    return ReportSummaryUtils;
}());
export { ReportSummaryUtils };
//# sourceMappingURL=report-summary-utils.js.map